package com.ruoyi.interfaces.service;

import com.ruoyi.common.core.domain.TreeSelect;
import com.ruoyi.common.core.domain.entity.SysMenu;
import com.ruoyi.interfaces.domain.MdDataCate;
import com.ruoyi.interfaces.domain.TreeSelectString;

import java.util.List;

/**
 * 数据项分类管理Service接口
 * 
 * @author 朱得糠
 * @date 2025-07-25
 */
public interface IMdDataCateService 
{
    /**
     * 查询数据项分类管理
     * 
     * @param cateId 数据项分类管理主键
     * @return 数据项分类管理
     */
    public MdDataCate selectMdDataCateByCateId(String cateId);

    /**
     * 查询数据项分类管理列表
     * 
     * @param mdDataCate 数据项分类管理
     * @return 数据项分类管理集合
     */
    public List<MdDataCate> selectMdDataCateList(MdDataCate mdDataCate);

    /**
     * 新增数据项分类管理
     * 
     * @param mdDataCate 数据项分类管理
     * @return 结果
     */
    public int insertMdDataCate(MdDataCate mdDataCate);

    /**
     * 修改数据项分类管理
     * 
     * @param mdDataCate 数据项分类管理
     * @return 结果
     */
    public int updateMdDataCate(MdDataCate mdDataCate);

    /**
     * 批量删除数据项分类管理
     * 
     * @param cateIds 需要删除的数据项分类管理主键集合
     * @return 结果
     */
    public int deleteMdDataCateByCateIds(String[] cateIds);

    /**
     * 删除数据项分类管理信息
     * 
     * @param cateId 数据项分类管理主键
     * @return 结果
     */
    public int deleteMdDataCateByCateId(String cateId);
    public List<TreeSelectString> buildDataTreeSelect(List<MdDataCate> menus);
}
